@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2003-2019 Christian Jaeger, copying@christianjaeger.ch
+# Copyright (c) 2003-2020 Christian Jaeger, copying@christianjaeger.ch
 #
 # This is free software, offered under either the same terms as perl 5
 # or the terms of the Artistic License version 2 or the terms of the
@@ -57,11 +57,11 @@ Creates new filehandle and calls builtin open, croaks on errors.
 
 Calls builtin, without/with error checking.
 
-=item xreadline
+=item xreadline ()
 
 Same as builtin readline, but checks $! for errors. (Not sure that really works.)
 
-=item xreadline_chomp
+=item xreadline_chomp ()
 
 Does xreadline and chomp's the result(s) (unless undefined).
 
@@ -80,6 +80,11 @@ end of file.
 
 # Yeah try it. Only string exception so far
 
+=item xreadchar ()
+
+Read one character (can be more than one byte from the source
+filehandle if an encoding is set on the filehandle).
+
 =item xsysreadcompletely( buf, length [,offset]) -> bool
 
 Like xsysread, but resumes reading upon intterrupted system calls and
@@ -442,6 +447,11 @@ sub xxreadchunk {
     $rv ? $buf : die "EOF\n";
 }
 
+sub xreadchar {
+    my $self = shift;
+    $self->xreadchunk(1)
+}
+
 sub sysread {
     my $self = shift;
     if    (@_ == 2) { CORE::sysread $self->fh, $_[0], $_[1] }
@@ -979,14 +989,14 @@ sub xrewind {
 
 sub xseek {
     my $self = shift;
-    @_ == 1 or @_ == 2 or croak "xseek: wrong number of arguments";
+    @_ == 1 or @_ == 2 or fp_croak_arity "1 or 2";
     seek $self->fh, $_[0], defined $_[1] ? $_[1] : SEEK_SET
         or croak "xseek on " . ($self->quotedname) . ": $!";
 }
 
 sub seek {
     my $self = shift;
-    @_ == 1 or @_ == 2 or croak "seek: wrong number of arguments";
+    @_ == 1 or @_ == 2 or fp_croak_arity "1 or 2";
     seek $self->fh, $_[0], defined $_[1] ? $_[1] : SEEK_SET;
 }
 
